Learn R Programming

EMMIXSSL (version 1.1.1)

loglk_full: Full log-likelihood function

Description

Full log-likelihood function with both terms of ignoring and missing

Usage

loglk_full(dat, zm, pi, mu, sigma, ncov = 2, xi)

Value

lk

Log-likelihood value

Arguments

dat

An \(n\times p\) matrix where each row represents an individual observation

zm

An n-dimensional vector containing the class labels including the missing-label denoted as NA.

pi

A g-dimensional vector for the initial values of the mixing proportions.

mu

A \(p \times g\) matrix for the initial values of the location parameters.

sigma

A \(p\times p\) covariance matrix if ncov=1, or a list of g covariance matrices with dimension \(p\times p \times g\) if ncov=2.

ncov

Options of structure of sigma matrix; the default value is 2; ncov = 1 for a common covariance matrix; ncov = 2 for the unequal covariance/scale matrices.

xi

A 2-dimensional vector containing the initial values of the coefficients in the logistic function of the Shannon entropy.

Details

The full log-likelihood function can be expressed as $$ \log L_{PC}^{({full})}(\boldsymbol{\Psi})=\log L_{PC}^{({ig})}(\theta)+\log L_{PC}^{({miss})}(\theta,\boldsymbol{\xi}),$$ where\(\log L_{PC}^{({ig})}(\theta)\)is the log likelihood function formed ignoring the missing in the label of the unclassified features, and \(\log L_{PC}^{({miss})}(\theta,\boldsymbol{\xi})\) is the log likelihood function formed on the basis of the missing-label indicator.